/*!
 * \file dac_ctrl.h
 * \brief DAC Controlドライバ
 * \author Hisashi IIDA
 *
 * \note
 * Copyright(C) 2012 Yamaha Corporation<br>
 * All rights reserved.<br>
 * $Id:$
 */
#ifndef __COMM_SPI_IF_H__
#define __COMM_SPI_IF_H__

#ifndef __KERNEL__
#include <sys/ioctl.h>      /* for _IOWR macro */
#endif
#include <stdbool.h>

#define COMM_SPI_BUF_SIZE             (64 * 1024)

#define COMM_SPI_TRANSFER_DEVICE_NAME   "comm_spi-dac1"
#define COMM_SPI_LOOPBACK_DEVICE_NAME   COMM_SPI_TRANSFER_DEVICE_NAME

#define CLOCK_GEN_IOCTL_TYPE (0x16) /*! XXX */

#define COMM_SPI_DEV_MAX_SPEED_HIGH         (2000000)
#define COMM_SPI_DEV_MAX_SPEED_LOW          (500000)
#define COMM_SPI_DEV_MAX_SPEED_LOOPBACK     (5000000)

typedef struct commSpiIoctlTransfer_struct {
    unsigned char           *txbuf;
    unsigned char           *rxbuf;
    unsigned long           bufsize;
    unsigned long           speed_hz;
} commSpiIoctlTransferParam;

typedef struct commSpiIoctlLoopback_struct {
    unsigned char           *txbuf;
    unsigned char           *rxbuf;
    unsigned long           bufsize;
    unsigned long           speed_hz;
} commSpiIoctlLoopbackParam;

typedef bool commSpiIoctlDMAFlag;

#define COMM_SPI_IOCTL_TRANSFER_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 1, commSpiIoctlTransferParam)

#define COMM_SPI_IOCTL_LOOPBACK_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 2, commSpiIoctlLoopbackParam)

/* McSPIをスレーブモードでAsync通信を行う際に使用 */
#define COMM_SPI_IOCTL_SET_DMA_FLAG_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 3, commSpiIoctlDMAFlag)

/* McSPIをスレーブモードでAsync通信を行う際に使用 */
#define COMM_SPI_IOCTL_GET_DMA_FLAG_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 4, commSpiIoctlDMAFlag)

#endif /* __COMM_SPI_IF_H__ */
