/*!
 * \file usb_err_if.h
 * \brief USBエラー情報取得
 * \author Hisashi IIDA
 *
 * \note
 * Copyright(C) 2014 Yamaha Corporation<br>
 * All rights reserved.<br>
 * $Id:$
 */
#ifndef __USB_ERR_IF_H__
#define __USB_ERR_IF_H__

#ifndef __KERNEL__
#include <sys/ioctl.h>      /* for _IOWR macro */
#endif

#define USBERR_IOCTL_TYPE   (0x19) /*! XXX */

/* イベント */
typedef enum {
    USB_ERR_EVENT_NONE              = 0,
    USB_ERR_EVENT_UNSUPPORT_DEVICE,
    USB_ERR_EVENT_HUB_NOT_SUPPORT,
    USB_ERR_EVENT_DEVICE_NO_RESPONSE,
}   USB_ERR_EVENT;

typedef enum {
    USB_ERR_STS_TRUE    = 0,
    USB_ERR_STS_FALSE
}   USB_ERR_STS;

typedef enum {
    USB_OVR_IOCTL_CMD_GET_VBUSERR_CONT           = _IO(USBERR_IOCTL_TYPE,  1),
    USB_OVR_IOCTL_CMD_GET_ERROR_EVENT            = _IO(USBERR_IOCTL_TYPE,  2),
    USB_OVR_IOCTL_CMD_GET_STS_UNSUPPORT_DEVICE   = _IO(USBERR_IOCTL_TYPE,  3),
    USB_OVR_IOCTL_CMD_GET_STS_HUB_NOT_SUPPORT    = _IO(USBERR_IOCTL_TYPE,  4),
    USB_OVR_IOCTL_CMD_GET_STS_DEVICE_NO_RESPONSE = _IO(USBERR_IOCTL_TYPE,  5),
}   USB_OVR_IOCTL_CMD;


#define COMM_SPI_TXBUF_SIZE             (64 * 1024)
#define COMM_SPI_RXBUF_SIZE             (64 * 1024)

#define COMM_SPI_TRANSFER_DEVICE_NAME   "comm_spi-dac1"
#define COMM_SPI_LOOPBACK_DEVICE_NAME   COMM_SPI_TRANSFER_DEVICE_NAME

#define CLOCK_GEN_IOCTL_TYPE (0x16) /*! XXX */

#define COMM_SPI_DEV_MAX_SPEED_HIGH         (2000000)
#define COMM_SPI_DEV_MAX_SPEED_LOW          (500000)
#define COMM_SPI_DEV_MAX_SPEED_LOOPBACK     (5000000)

typedef struct commSpiIoctlTransfer_struct {
    const unsigned char     *txbuf;
    unsigned char           *rxbuf;
    unsigned long           txbufsize;
    unsigned long           rxbufsize;
    unsigned long           speed_hz;
} commSpiIoctlTransferParam;

typedef struct commSpiIoctlLoopback_struct {
    const unsigned char     *txbuf;
    unsigned char           *rxbuf;
    unsigned long           bufsize;
    unsigned long           speed_hz;
} commSpiIoctlLoopbackParam;

#define COMM_SPI_IOCTL_TRANSFER_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 1, commSpiIoctlTransferParam)

#define COMM_SPI_IOCTL_LOOPBACK_CMD \
    _IOWR(CLOCK_GEN_IOCTL_TYPE, 2, commSpiIoctlLoopbackParam)

#endif /* __USB_ERR_IF_H__ */
